Skip to contents

Uses the Wald test to pairwise compare features in both models. The Wald test is defined as \(W = \frac {(\beta_{1} - \beta_{2}) ^2}{\operatorname {se}(\beta_{1})^2 + \operatorname {se}(\beta_{2})^2} \)

Usage

compare_models()

Details

Creates csv files in extdata/wald/<binary|multinomial> containing the model weights and the Wald test and p values.