Compare feature importance of models using the Wald test
compare_models.RdUses the Wald test to pairwise compare features in both models. The Wald test is defined as \(W = \frac {(\beta_{1} - \beta_{2}) ^2}{\operatorname {se}(\beta_{1})^2 + \operatorname {se}(\beta_{2})^2} \)