Create Model Weights tables
create_model_weights_tables.RdDisplays the model weights, constant, Null log-likelihood and estimated model log-likelihood and
adjusted rho-squared of the binary and multinomial models for each model separately and a large
combined table for across all groups of each model type.
Saves the tables as extdata/tables/<binary|multinomial>/model_weights_<group>.html using the
gt package.
Examples
tables <- baitlist::create_model_weights_tables()
#> Creating model weights tables...
#> Processing All participants model (binary)...
#> Processing Amsterdam UMC model (binary)...
#> Processing OLVG model (binary)...
#> Processing Intensivists model (binary)...
#> Processing Fellows model (binary)...
#> Creating combined table across group (binary)...
#> Processing All participants model (multinomial)...
#> Processing Amsterdam UMC model (multinomial)...
#> Processing OLVG model (multinomial)...
#> Processing Intensivists model (multinomial)...
#> Processing Fellows model (multinomial)...
#> Creating combined table across group (multinomial)...
#> Done.
tables$binary$aggregate
All participants model
Goodness of Fit