Create pooled group comparison table (interaction models)
create_pooled_group_comparison_tables.RdUses pooled Apollo models with group interaction terms (d_*) to compare coefficients between subgroups for both binary and multinomial models.
create_pooled_group_comparison_tables.RdUses pooled Apollo models with group interaction terms (d_*) to compare coefficients between subgroups for both binary and multinomial models.